@@ -26,7 +26,7 @@ def definePump(address: str, type: util.PSDTypes, baudRate=9600, resolutionMode=
     if len(pumps) < pumpLength:
         newPump = PSD(address, type, baudRate, resolutionMode)
         print("Enable h Factor Commands and Queries")
-        sendCommand(newPump.asciiAddress, newPump.command.enableFactorCommands(True) + newPump.command.executeCommandBuffer())
+        sendCommand(newPump.asciiAddress, newPump.command.enableHFactorCommandsAndQueries() + newPump.command.executeCommandBuffer())
         result = sendCommand(newPump.asciiAddress, newPump.command.syringeModeQuery(), True)
         resolution = result[3:4]
         newPump.setResolution(int(resolution))
