@@ -12,7 +12,6 @@ class Command:
     Yx - Initialize PSD/4, Assign Valve Output to Left
     Wx - Initialize PSD/4, Configure for No Valve
     """
-
     def initialize(self, drive: str, value=0):
         cmd: str = ''
         if drive == 'Z' or drive == 'Y' or drive == 'W':
@@ -29,7 +28,6 @@ class Command:
     R - Execute Command Buffer
     X - Execute Command Buffer from Beginning
     """
-
     def executeCommandBuffer(self, type='R'):
         cmd: str = ''
         if type == 'R' or type == 'X':
@@ -43,29 +41,35 @@ class Command:
         Syringe Commands
     """
 
+    # z - Set Counter Position
     def setCounterPosition(self):
         return 'z'
 
+    # Ax - Absolute Position
     def absolutePosition(self, value):
         cmd: str = 'A'
         cmd += str(value)
         return cmd
 
+    # Px - Relative Pickup
     def relativePickup(self, value: int):
         cmd: str = 'P'
         cmd += str(value)
         return cmd
 
+    # Dx - Relative Dispense
     def relativeDispense(self, value: int):
         cmd: str = 'D'
         cmd += str(value)
         return cmd
 
+    # Kx - Return Steps
     def returnSteps(self, value: int):
         cmd: str = 'K'
         cmd += str(value)
         return cmd
 
+    # kx - Back-off Steps
     def backoffSteps(self, value: int):
         cmd: str = 'k'
         cmd += str(value)
@@ -75,6 +79,7 @@ class Command:
         Valve Commands
     '''
 
+    # Ix - Move Valve to Input Position
     def moveValveToInputPosition(self, value=0):
         cmd: str = 'I'
         if value == 0:
@@ -82,10 +87,11 @@ class Command:
         elif 1 <= value <= 8:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for Move valve to input position command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for Move valve to input position command!")
         return cmd
 
+    # Ox - Move Valve to Output Position
     def moveValveToOutputPosition(self, value=0):
         cmd: str = 'O'
         if value == 0:
@@ -93,13 +99,15 @@ class Command:
         elif 1 <= value <= 8:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for Move valve to output position command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for Move valve to output position command!")
         return cmd
 
+    # B - Move Valve to Bypass (Throughput Position)
     def moveValveToBypass(self):
         return 'B'
 
+    # E - Move Valve to Extra Position
     def moveValveToExtraPosition(self):
         return 'E'
 
@@ -107,9 +115,9 @@ class Command:
         Action commands
     """
 
+    # g - Define a Position in a Command String
     def definePositionInCommandString(self):
-        cmd: str = 'g'
-        return cmd
+        return 'g'
 
     # Gx - Repeat Commands
     def repeatCommands(self, value=0):
@@ -119,9 +127,8 @@ class Command:
         elif 1 <= value <= 65535:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for Repeat Commands command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for Repeat Commands command!")
-
         return cmd
 
     # Mx - Delay - performs a delay of x milliseconds.where 5 ≤ x ≤ 30,000 milliseconds.
@@ -130,8 +137,8 @@ class Command:
         if 5 <= value <= 30000:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for Delay command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for Delay command!")
         return cmd
 
     # Hx - Halt Command Execution
@@ -140,8 +147,8 @@ class Command:
         if 0 <= value <= 2:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for Halt command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for Halt command!")
         return cmd
 
     # Jx - Auxiliary Outputs
@@ -150,8 +157,8 @@ class Command:
         if 0 <= value <= 7:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for Auxiliary Outputs command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for Auxiliary Outputs command!")
         return cmd
 
     # sx - Store Command String
@@ -161,8 +168,8 @@ class Command:
             cmd += str(location)
             cmd += command
         else:
+            print("Invalid value " + str(location) + " for Store Command String command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for Store Command String command!")
         return cmd
 
     # ex - Execute Command String in EEPROM Location
@@ -171,8 +178,8 @@ class Command:
         if 0 <= location <= 14:
             cmd += str(location)
         else:
+            print("Invalid value " + str(location) + " for Execute Command String in EEPROM Location command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for Execute Command String in EEPROM Location command!")
         return cmd
 
     def terminateCommandBuffer(self):
@@ -187,8 +194,8 @@ class Command:
         if 0 <= value <= 20:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for Set acceleration command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for set acceleration command!")
         return cmd
 
     def setSpeed(self, value: int):
@@ -196,8 +203,8 @@ class Command:
         if 1 <= value <= 40:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for Set speed command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for set speed command!")
         return cmd
 
     def increaseStopVelocityBySteps(self, value: int):
@@ -205,8 +212,8 @@ class Command:
         if 0 <= value <= 25:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for Increase Stop Velocity by Steps command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for Increase Stop Velocity by Steps command!")
         return cmd
 
     def setStartVelocity(self, value: int):
@@ -214,8 +221,8 @@ class Command:
         if 50 <= value <= 1000:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for Set start velocity command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for set start velocity command!")
         return cmd
 
     def setMaximumVelocity(self, value: int):
@@ -223,8 +230,8 @@ class Command:
         if 2 <= value <= 5800:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for Set maximum velocity command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for set maximum velocity command!")
         return cmd
 
     def stopVelocity(self, value: int):
@@ -232,8 +239,8 @@ class Command:
         if 50 <= value <= 2700:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for Stop velocity command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for stop velocity command!")
         return cmd
 
     """
@@ -242,12 +249,10 @@ class Command:
     """
 
     def enableHFactorCommandsAndQueries(self):
-        cmd: str = 'h30001'
-        return cmd
+        return "h30001"
 
     def disableHFactorCommandsAndQueries(self):
-        cmd: str = 'h30000'
-        return cmd
+        return "h30000"
 
     def resetPSD(self):
         return "h30003"
@@ -261,7 +266,10 @@ class Command:
         # permitted values between 0-40
         if 0 <= speedCode <= 40:
             cmdValue += speedCode
-        cmd += str(cmdValue)
+            cmd += str(cmdValue)
+        else:
+            print("Invalid speed code " + str(speedCode) + " for Initialize Syringe Only command!")
+            cmd = 'cmdError'
         return cmd
 
     def setSyringeMode(self, mode: int):
@@ -270,36 +278,54 @@ class Command:
         # permitted values between 0-15
         if 0 <= mode <= 15:
             cmdValue += mode
-        cmd += str(cmdValue)
-        print("default syringe mode method call")
-        print(cmd)
+            cmd += str(cmdValue)
+        else:
+            print("Invalid mode " + str(mode) + " for Set Syringe Mode command!")
+            cmd = 'cmdError'
         return cmd
 
     def enableValveMovement(self):
-        cmd: str = 'h20001'
-        return cmd
+        return "h20001"
 
     def disableValveMovement(self):
-        cmd: str = 'h20002'
-        return cmd
+        return "h20002"
 
     def setValveType(self, type: int):
         cmd: str = 'h2100'
         # permitted values between 0-6
         if 0 <= type <= 6:
             cmd += str(type)
+        else:
+            print("Invalid valve type " + str(type) + " for Set Valve Type command!")
+            cmd = 'cmdError'
         return cmd
 
-    def moveValveToSpecificPositionInShortestDirection(self, specificPosition: PositionInShortestDirection):
-        cmd: str = 'h2300'
-        cmd += str(specificPosition.value)
-        return cmd
+    def moveValveToInputPositionInShortestDirection(self):
+        return "h23001"
+
+    def moveValveToOutputPositionInShortestDirection(self):
+        return "h23002"
+
+    def moveValveToWashPositionInShortestDirection(self):
+        return "h23003"
+
+    def moveValveToReturnPositionInShortestDirection(self):
+        return "h23004"
+
+    def moveValveToBypassPositionInShortestDirection(self):
+        return "h23005"
+
+    def moveValveToExtraPositionInShortestDirection(self):
+        return "h23006"
 
     def moveValveClockwiseDirection(self, position: int):
         cmd: str = 'h2400'
         # permitted values between 1-8
         if 1 <= position <= 8:
             cmd += str(position)
+        else:
+            print("Invalid position " + str(position) + " for Move Valve in Clockwise Direction command!")
+            cmd = 'cmdError'
         return cmd
 
     def moveValveCounterclockwiseDirection(self, position: int):
@@ -307,6 +333,9 @@ class Command:
         # permitted values between 1-8
         if 1 <= position <= 8:
             cmd += str(position)
+        else:
+            print("Invalid position " + str(position) + " for Move Valve in Counterclockwise Direction command!")
+            cmd = 'cmdError'
         return cmd
 
     def moveValveInShortestDirection(self, position: int):
@@ -314,24 +343,29 @@ class Command:
         # permitted values between 1-8
         if 1 <= position <= 8:
             cmd += str(position)
+        else:
+            print("Invalid position " + str(position) + " for Move Valve in Shortest Direction command!")
+            cmd = 'cmdError'
         return cmd
 
-    def valveMovementHelper(self, cmdValue: int, incrementWith: int):
+    def angularValveMoveCommandCtr(self, cmdValue: int, incrementWith: int):
         cmd: str = 'h'
         # permitted values between 0-345 incremented by 15
         if 345 >= incrementWith >= 0 == incrementWith % 15:
             cmdValue += incrementWith
-        cmd += str(cmdValue)
+        else:
+            print("Invalid angle value " + str(incrementWith) + " for Angular Valve Move command!")
+            cmd = 'cmdError'
         return cmd
 
     def clockwiseAngularValveMove(self, position: int):
-        return self.valveMovementHelper(27000, position)
+        return self.angularValveMoveCommandCtr(27000, position)
 
     def counterclockwiseAngularValveMove(self, position: int):
-        return self.valveMovementHelper(28000, position)
+        return self.angularValveMoveCommandCtr(28000, position)
 
     def shortestDirectAngularValveMove(self, position: int):
-        return self.valveMovementHelper(29000, position)
+        return self.angularValveMoveCommandCtr(29000, position)
 
     """
         Query Commands
