@@ -18,7 +18,7 @@ class CommandPSD6(Command):
         if self.checkValueInInterval(value, 6000, 48000):
             cmd += str(value)
         else:
-            print("Wrong parameter value for PSD6 absolute position command!")
+            print("Invalid value " + str(value) + " for PSD6 absolute position command!")
             cmd = 'cmdError'
         return cmd
 
@@ -28,7 +28,7 @@ class CommandPSD6(Command):
         if self.checkValueInInterval(value, 6000, 48000):
             cmd += str(value)
         else:
-            print("Wrong parameter value for PSD6 absolute position with ready status command!")
+            print("Invalid value " + str(value) + " for PSD6 absolute position with ready status command!")
             cmd = 'cmdError'
         return cmd
 
@@ -38,7 +38,7 @@ class CommandPSD6(Command):
         if self.checkValueInInterval(value, 6000, 48000):
             cmd += str(value)
         else:
-            print("Wrong parameter value for relative pickup command!")
+            print("Invalid value " + str(value) + " for PSD6 relative pickup command!")
             cmd = 'cmdError'
         return cmd
 
@@ -48,7 +48,7 @@ class CommandPSD6(Command):
         if self.checkValueInInterval(value, 6000, 48000):
             cmd += str(value)
         else:
-            print("Wrong parameter value for PSD6 relative pickup with ready status command!")
+            print("Invalid value " + str(value) + " for PSD6 relative pickup with ready status command!")
             cmd = 'cmdError'
         return cmd
 
@@ -58,7 +58,7 @@ class CommandPSD6(Command):
         if self.checkValueInInterval(value, 6000, 48000):
             cmd += str(value)
         else:
-            print("Wrong parameter value for PSD6 relative dispense command!")
+            print("Invalid value " + str(value) + " for PSD6 relative dispense command!")
             cmd = 'cmdError'
         return cmd
 
@@ -68,7 +68,7 @@ class CommandPSD6(Command):
         if self.checkValueInInterval(value, 6000, 48000):
             cmd += str(value)
         else:
-            print("Wrong parameter value for PSD6 relative dispense with ready status command!")
+            print("Invalid value " + str(value) + " for PSD6 relative dispense with ready status command!")
             cmd = 'cmdError'
         return cmd
 
@@ -78,7 +78,7 @@ class CommandPSD6(Command):
         if self.checkValueInInterval(value, 100, 800):
             cmd += str(value)
         else:
-            print("Wrong parameter value for PSD6 return steps command!")
+            print("Invalid value " + str(value) + " for PSD6 return steps command!")
             cmd = 'cmdError'
         return cmd
 
@@ -88,7 +88,7 @@ class CommandPSD6(Command):
         if self.checkValueInInterval(value, 200, 1600):
             cmd += str(value)
         else:
-            print("Wrong parameter value for PSD6 backoff steps command!")
+            print("Invalid value " + str(value) + " for PSD6 backoff steps command!")
             cmd = 'cmdError'
         return cmd
 
@@ -126,8 +126,8 @@ class CommandPSD6(Command):
         if 50 <= value <= 1000:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for PSD6 start velocity command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for set start velocity command!")
         return cmd
 
     def setMaximumVelocity(self, value: int):
@@ -135,8 +135,8 @@ class CommandPSD6(Command):
         if 2 <= value <= 5800:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for PSD6 set maximum velocity command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for set maximum velocity command!")
         return cmd
 
     def stopVelocity(self, value: int):
@@ -144,6 +144,6 @@ class CommandPSD6(Command):
         if 50 <= value <= 2700:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for PSD6 stop velocity command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for stop velocity command!")
         return cmd
