@@ -92,12 +92,11 @@ class PSD:
 
     def checkValidity(self, command: str):
         result: bool = False
-        print("Check validity for command " + command)
-
         countg = command.count("g")
         countG = command.count("G")
 
         if "cmdError" not in command:
+            print(command + " validity is checked...")
             commandType = self.getTypeOfCommand(command)
             if (commandType == 0b0010 or commandType == 0b0100 or commandType == 0b0001) and \
                     self.checkGgPairs(countg, countG):
@@ -105,7 +104,7 @@ class PSD:
             else:
                 print()
         else:
-            print("Error! Wrong command! Check manual!")
+            print("The current command is wrong! Please check the manual!")
 
         return result
 
